@@ -9,7 +9,9 @@ class ReLUDerivatives(ElementwiseDerivatives):
         return ReLU
 
     def hessian_is_zero(self):
+        """`ReLU''(x) = 0`."""
         return True
 
     def df(self, module, g_inp, g_out):
+        """First ReLU derivative: `ReLU'(x) = 0 if x < 0 else 1`. """
         return gt(module.input0, 0).float()
