@@ -2,21 +2,23 @@
 BackPACK Extensions
 """
 
-from .curvmatprod import CMP
+from .curvmatprod import GGNMP, HMP, PCHMP
 from .firstorder import BatchGrad, BatchL2Grad, SumGradSquared, Variance
 from .secondorder import (
+    HBP,
     KFAC,
     KFLR,
     KFRA,
-    HBP,
+    DiagGGN,
     DiagGGNExact,
     DiagGGNMC,
-    DiagGGN,
     DiagHessian,
 )
 
 __all__ = [
-    "CMP",
+    "PCHMP",
+    "GGNMP",
+    "HMP",
     "BatchL2Grad",
     "BatchGrad",
     "SumGradSquared",
