@@ -1,8 +1,24 @@
-from torch.nn import Conv2d, Linear
+from torch.nn import (
+    Conv1d,
+    Conv2d,
+    Conv3d,
+    ConvTranspose1d,
+    ConvTranspose2d,
+    ConvTranspose3d,
+    Linear,
+)
 
 from backpack.extensions.backprop_extension import BackpropExtension
 
-from . import conv2d, linear
+from . import (
+    conv1d,
+    conv2d,
+    conv3d,
+    convtranspose1d,
+    convtranspose2d,
+    convtranspose3d,
+    linear,
+)
 
 
 class BatchL2Grad(BackpropExtension):
@@ -26,6 +42,11 @@ class BatchL2Grad(BackpropExtension):
             fail_mode="WARNING",
             module_exts={
                 Linear: linear.BatchL2Linear(),
+                Conv1d: conv1d.BatchL2Conv1d(),
                 Conv2d: conv2d.BatchL2Conv2d(),
+                Conv3d: conv3d.BatchL2Conv3d(),
+                ConvTranspose1d: convtranspose1d.BatchL2ConvTranspose1d(),
+                ConvTranspose2d: convtranspose2d.BatchL2ConvTranspose2d(),
+                ConvTranspose3d: convtranspose3d.BatchL2ConvTranspose3d(),
             },
         )
