@@ -1,8 +1,24 @@
-from torch.nn import Conv2d, Linear
+from torch.nn import (
+    Conv1d,
+    Conv2d,
+    Conv3d,
+    ConvTranspose1d,
+    ConvTranspose2d,
+    ConvTranspose3d,
+    Linear,
+)
 
 from backpack.extensions.backprop_extension import BackpropExtension
 
-from . import conv2d, linear
+from . import (
+    conv1d,
+    conv2d,
+    conv3d,
+    convtranspose1d,
+    convtranspose2d,
+    convtranspose3d,
+    linear,
+)
 
 
 class SumGradSquared(BackpropExtension):
@@ -23,5 +39,13 @@ class SumGradSquared(BackpropExtension):
         super().__init__(
             savefield="sum_grad_squared",
             fail_mode="WARNING",
-            module_exts={Linear: linear.SGSLinear(), Conv2d: conv2d.SGSConv2d(),},
+            module_exts={
+                Linear: linear.SGSLinear(),
+                Conv1d: conv1d.SGSConv1d(),
+                Conv2d: conv2d.SGSConv2d(),
+                Conv3d: conv3d.SGSConv3d(),
+                ConvTranspose1d: convtranspose1d.SGSConvTranspose1d(),
+                ConvTranspose2d: convtranspose2d.SGSConvTranspose2d(),
+                ConvTranspose3d: convtranspose3d.SGSConvTranspose3d(),
+            },
         )
