@@ -18,9 +18,9 @@ The implemented extensions are
 - The diagonal of the Hessian :func:`DiagHessian <backpack.extensions.DiagHessian>`
 """
 
-from .diag_ggn import DiagGGNExact, DiagGGNMC, DiagGGN
+from .diag_ggn import DiagGGN, DiagGGNExact, DiagGGNMC
 from .diag_hessian import DiagHessian
-from .hbp import KFAC, KFLR, KFRA, HBP
+from .hbp import HBP, KFAC, KFLR, KFRA
 
 __all__ = [
     "DiagGGNExact",
