@@ -22,7 +22,9 @@ def load_mnist_dataset():
 def get_mnist_dataloder(batch_size=64, shuffle=True):
     """Returns a dataloader for MNIST"""
     return torch.utils.data.dataloader.DataLoader(
-        load_mnist_dataset(), batch_size=batch_size, shuffle=shuffle,
+        load_mnist_dataset(),
+        batch_size=batch_size,
+        shuffle=shuffle,
     )
 
 
